@@ -12,15 +12,16 @@ master_doc = 'index'
 project = u'sphinxcontrib-ansi'
 copyright = u'2010, Sebastian Wiesner'
 version = '0.5'
-release = '0.5'
+release = '0.5.1'
 
 exclude_patterns = ['_build']
 
 html_theme = 'default'
 html_static_path = []
 
-intersphinx_mapping = {'http://docs.python.org/': None,
-                       'http://sphinx.pocoo.org/': None,}
+intersphinx_mapping = {'python': ('http://docs.python.org/', None)}
+                       # broken in Sphinx 1.0
+                       # 'sphinx': ('http://sphinx.pocoo.org/', None)}
 
 issuetracker = 'bitbucket'
 issuetracker_user = 'birkenfeld'
